Module config

Module config 

Structs

AppConfig
FieldGroup
FieldSubgroup

Functions

default_true
field_description
Get description for a field by its env suffix
global_config_path
Global config file path
save_auto_update_preference
Save only the auto_update preference to global config without overwriting other fields