pub fn preset_is_modified(cfg: &AppConfig, snapshot: &LlmPresetFields) -> boolExpand description
Check if current config fields differ from the loaded preset snapshot.
pub fn preset_is_modified(cfg: &AppConfig, snapshot: &LlmPresetFields) -> boolCheck if current config fields differ from the loaded preset snapshot.