Structs
Functions
- default_
true - field_
description - Get description for a field by its env suffix
- global_
config_ path - Global config file path
- save_
auto_ update_ preference - Save only the auto_update preference to global config without overwriting other fields