Functions
- commit_
is_ merge - commit_
is_ pushed - compute_
next_ minor_ tag - Compute the next minor semver tag from latest tag.
- create_
tag - Create a git lightweight tag.
- ensure_
ancestor_ of_ head - ensure_
commit_ exists - ensure_
head_ exists - filter_
diff_ by_ globs - Filter unified diff to exclude files matching glob patterns. Files matching any pattern are removed from the diff output but will still be committed.
- find_
repo_ root - Find the git repository root directory
- get_
commit_ diff - get_
latest_ tag - Returns the latest tag according to git version sorting.
- get_
range_ diff - get_
staged_ diff - Get the output of
git diff --staged - get_
staged_ diff_ filtered - Get staged diff with files filtered by glob patterns. Excluded files are still committed, just not sent to the LLM for analysis.
- has_
upstream_ branch - head_
is_ merge_ commit - Returns true if HEAD has multiple parents
- is_
head_ commit - is_
head_ pushed - Returns true when HEAD exists on upstream branch
- list_
staged_ files - List staged file paths
- rewrite_
commit_ message - run_
commit - Run
git commit -m "<message>" [extra_args...] - run_
push - Run
git push - undo_
last_ commit_ soft - Undo latest commit, keep all changes staged